# NanoB2B::Example.pm 
#
# Perl implementation of an example module 
#
# Copyright (c) 2016,
#
# Bridget T McInnes, University of Minnesota, Twin Cities
# bmcinnes at vcu.edu 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to 
#
# The Free Software Foundation, Inc., 
# 59 Temple Place - Suite 330, 
# Boston, MA  02111-1307, USA.

=head1 NAME

NanoB2B::Example - is an example module for a tutorial on setting up a perl
module for CPAN release

=head1 SYNOPSIS

 use NanoB2B::Example;
 
 my $module = NanoB2B::Example->new(); 
 my $name = "Bridget"; 
 
 my $string = $module->getHello($name); 
 print "$string\n";

 use NanoB2B::Example;

 
=head1 DESCRIPTION

NanoB2B::Example is an example module for a tutorial on setting up a perl
module for CPAN release

=cut

package NanoB2B::Example.pm;

my $pkg = "UMLS::Association";

use Fcntl;
use strict;
use warnings;

use vars qw($VERSION);

$VERSION = '0.01';


# -------------------- Class methods start here --------------------

#  method to create a new UMLS::Association object
#  input : $params <- reference to hash containing the parameters 
#  output:

sub new
{
    my $className = shift;
    return undef if(ref $className);

    my $self = {};
    
    # The backend interface object.
    $self->{'interface'} = $interface;

    # Bless object, initialize it and return it.
    bless($self, $className);

    return $self;
}

=head3 getHello

description:

 function to set a hello string 

input:   

 $name <- string containing person you are saying 
            hello to

output:

 $string <- string containing greeting 

example:

 use NanoB2B::Example;
 my $module = NanoB2B::Example->new(); 
	 
 my $name = "Bridget"; 
 my $greeting = $module->getHello($name); 
  
 print "$greeting\n";

=cut
sub getHello
{
    my $self = shift; 
    my $name = shift; 

    my $value = "Hello $name!";
    
    return $value;
}

1;

__END__

=head1 REFERENCING

    If you have a reference paper for this module put it here in bibtex form

=head1 CONTACT US

  If you have any trouble installing and using <module name> 
  please contact us via the users mailing list :

      mailing list email 

  You can join this group by going to:

      http://tech.groups.yahoo.com/group/<group name> 

  You may also contact us directly if you prefer :

      Bridget T. McInnes: btmcinnes at vcu.edu

=head1 SEE ALSO

Additional modules associated with the package

=head1 AUTHORS

  Bridget McInnes <btmcinnes at vcu.edu>

=head1 COPYRIGHT AND LICENSE

Copyright 2016 by Bridget McInnes

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to 

 The Free Software Foundation, Inc.,
 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA.

=cut
